@@ -16,7 +16,9 @@ from c8y_api.model.identity import Identity
 from c8y_api.model.binaries import Binaries
 from c8y_api.model.inventory import Inventory, DeviceInventory, DeviceGroupInventory
 from c8y_api.model.measurements import Measurements
+from c8y_api.model.notification2 import Subscriptions, Tokens
 from c8y_api.model.operations import Operations
+from c8y_api.model.tenant_options import TenantOptions
 
 
 class CumulocityApi(CumulocityRestApi):
@@ -42,6 +44,9 @@ class CumulocityApi(CumulocityRestApi):
         self.__events = Events(self)
         self.__alarms = Alarms(self)
         self.__operations = Operations(self)
+        self.__tenant_options = TenantOptions(self)
+        self.__notification2_subscriptions = Subscriptions(self)
+        self.__notification2_tokens = Tokens(self)
 
     @property
     def measurements(self) -> Measurements:
@@ -112,3 +117,18 @@ class CumulocityApi(CumulocityRestApi):
     def operations(self) -> Operations:
         """Provide access to the Operation API."""
         return self.__operations
+
+    @property
+    def tenant_options(self) -> TenantOptions:
+        """Provide access to the Tenant Options API."""
+        return self.__tenant_options
+
+    @property
+    def notification2_subscriptions(self) -> Subscriptions:
+        """Provide access to the Notification 2.0 Subscriptions API."""
+        return self.__notification2_subscriptions
+
+    @property
+    def notification2_tokens(self) -> Tokens:
+        """Provide access to the Notification 2.0 Tokens API."""
+        return self.__notification2_tokens
